@@ -211,8 +211,6 @@ class ExSTraCS(BaseEstimator,ClassifierMixin):
             try:
                 if not self.checkIsInt(random_state):
                     raise Exception("random_state param must be integer")
-                random.seed(int(random_state))
-                np.random.seed(int(random_state))
             except:
                 raise Exception("random_state param must be integer or None")
 
@@ -304,6 +302,10 @@ class ExSTraCS(BaseEstimator,ClassifierMixin):
         if self.learning_iterations == self.iterationCount and self.reboot_filename != None:
             raise Exception("You cannot call fit(X,y) a second time with a rebooted population.")
 
+        if self.random_state != None:
+            random.seed(int(self.random_state))
+            np.random.seed(int(self.random_state))
+
         if self.reboot_filename == None and self.hasTrained:
             self.iterationCount = 0
             self.population = ClassifierSet()
@@ -663,6 +665,18 @@ class ExSTraCS(BaseEstimator,ClassifierMixin):
             raise Exception(
                 "There are no final attribute cooccurences to return, as the ExSTraCS model has not been trained")
 
+    def get_attribute_tracking_scores(self,instance_labels=np.array([])):
+        if self.hasTrained:
+            retList = []
+            if instance_labels.size != self.env.formatData.numTrainInstances:
+                raise Exception('# of Instance Labels must match # of training instances')
+
+            for i in range(self.env.formatData.numTrainInstances):
+                retList.append([instance_labels[i], self.AT.attAccuracySums[self.env.formatData.shuffleOrder[i]]])
+            return retList
+        else:
+            raise Exception("There is no AT scores to return, as the ExSTraCS model has not been trained")
+
     ##Export Methods##
     def export_iteration_tracking_data(self,filename='iterationData.csv'):
         if self.hasTrained:
